# to execute this script using quartus_sh for generating Quartus QPF and QSF accordingly
#   quartus_sh --script=create_ghrd_quartus.tcl
#
set devicefamily ARRIAV
set device 5ASTFD5K3F40I3
set projectname  ghrd_5astfd5k3
set qipfiles "ghrd_5astfd5k3/synthesis/ghrd_5astfd5k3.qip,ip/altsource_probe/hps_reset.qip"
set hdlfiles "ip/edge_detect/altera_edge_detector.v,ip/debounce/debounce.v,ghrd_5astfd5k3_top.v"
set topname ghrd_5astfd5k3_top

# ... alternatively, for script to be used for both 5ASXFB5H4F40I3ES (fab A board) and 
source ./design_config.tcl
set fpga_pcie $PCIE_ENABLE
# 5ASTFD5K3F40I3ES (fab B board), above parameters can be passed in as script arguments
#   quartus_sh --script=create_ghrd_quartus.tcl <parameter1 value1 parameter2 value2 ...>
# parameters of this TCL includes
#   devicefamily  : FPGA device family
#   device        : FPGA device number
#   projectname   : Quartus project name
#   qipfiles      : QIP file path(s), multiple paths need seperator of ","
#   hdlfiles      : HDL file path(s), multiple paths need seperator of ","
#   topname       : top module name


proc show_arguments {} {
  global quartus
  global devicefamily
  global device
  global projectname
  global topname
  global qipfiles
  global hdlfiles
  global fpga_pcie

  foreach {key value} $quartus(args) {
    puts "-> Accepted parameter: $key,  \tValue: $value"
    if {$key == "devicefamily"} {
      set devicefamily $value
    }
    if {$key == "device"} {
      set device $value
    }
    if {$key == "projectname"} {
      set projectname $value
    }
    if {$key == "topname"} {
      set topname $value
    }
    if {$key == "qipfiles"} {
      set qipfiles $value
    }
    if {$key == "hdlfiles"} {
      set hdlfiles $value
    }
	if {$key == "fpga_pcie"} {
      set fpga_pcie $value
    }

  }
}
show_arguments

#regsub -all {\mfoo\M} $string bar string
#set wordList [regexp -inline -all -- {\S+} $text]
if {[regexp {,} $qipfiles]} {
  set qipfilelist [split $qipfiles ,]
} else {
  set qipfilelist $qipfiles
}

if {[regexp {,} $hdlfiles]} {
  set hdlfilelist [split $hdlfiles ,]
} else {
  set hdlfilelist $hdlfiles
}

project_new -overwrite -family $devicefamily -part $device $projectname

set_global_assignment -name TOP_LEVEL_ENTITY $topname

foreach qipfile $qipfilelist {
  set_global_assignment -name QIP_FILE $qipfile
}

foreach hdlfile $hdlfilelist {
  set_global_assignment -name VERILOG_FILE $hdlfile
}

if {$fpga_pcie == 1} {
set_global_assignment -name OPTIMIZATION_TECHNIQUE SPEED
set_global_assignment -name SYNTH_TIMING_DRIVEN_SYNTHESIS ON
set_global_assignment -name OPTIMIZE_HOLD_TIMING "ALL PATHS"
set_global_assignment -name FITTER_EFFORT "STANDARD FIT"
set_global_assignment -name PRE_MAPPING_RESYNTHESIS ON
set_global_assignment -name FINAL_PLACEMENT_OPTIMIZATION ALWAYS
set_global_assignment -name OPTIMIZATION_MODE "HIGH PERFORMANCE EFFORT"
set_global_assignment -name ROUTER_TIMING_OPTIMIZATION_LEVEL MAXIMUM
}

set_global_assignment -name PROJECT_OUTPUT_DIRECTORY output_files
set_global_assignment -name EDA_SIMULATION_TOOL "<None>"
set_global_assignment -name EDA_OUTPUT_DATA_FORMAT NONE -section_id eda_simulation
set_global_assignment -name SDC_FILE ghrd_timing.sdc

if {$fpga_pcie == 1} {
set_global_assignment -name SDC_FILE fpga_pcie.sdc
}
# enabling signaltap 
set_global_assignment -name ENABLE_SIGNALTAP ON
set_global_assignment -name USE_SIGNALTAP_FILE cti_tapping.stp
set_global_assignment -name SIGNALTAP_FILE cti_tapping.stp

# pin location assignments
set_location_assignment PIN_AW23 -to fpga_button_pio[3]
set_location_assignment PIN_AW24 -to fpga_button_pio[2]
set_location_assignment PIN_AP24 -to fpga_button_pio[1]
set_location_assignment PIN_AT23 -to fpga_button_pio[0]
set_location_assignment PIN_AU32 -to fpga_clk_50
set_location_assignment PIN_AU23 -to fpga_dipsw_pio[3]
set_location_assignment PIN_AE24 -to fpga_dipsw_pio[2]
set_location_assignment PIN_AF24 -to fpga_dipsw_pio[1]
set_location_assignment PIN_AL24 -to fpga_dipsw_pio[0]
set_location_assignment PIN_AD24 -to fpga_led_pio[3]
set_location_assignment PIN_AT24 -to fpga_led_pio[2]
set_location_assignment PIN_AU24 -to fpga_led_pio[1]
set_location_assignment PIN_AH24 -to fpga_led_pio[0]

if {$fpga_pcie == 1} {
set_instance_assignment -name AUTO_OPEN_DRAIN_PINS ON -to pcie_perstn_out
set_location_assignment PIN_AF8 -to hps_pcie_hip_avmm_refclk_clk
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to hps_pcie_hip_avmm_refclk_clk
set_location_assignment PIN_AK6 -to hps_pcie_hip_avmm_npor_pin_perst
set_instance_assignment -name IO_STANDARD "2.5 V" -to hps_pcie_hip_avmm_npor_pin_perst
set_location_assignment PIN_AU1 -to hps_pcie_hip_avmm_hip_serial_rx_in0
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to hps_pcie_hip_avmm_hip_serial_rx_in0
set_location_assignment PIN_AR1 -to hps_pcie_hip_avmm_hip_serial_rx_in1
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to hps_pcie_hip_avmm_hip_serial_rx_in1
set_location_assignment PIN_AN1 -to hps_pcie_hip_avmm_hip_serial_rx_in2
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to hps_pcie_hip_avmm_hip_serial_rx_in2
set_location_assignment PIN_AL1 -to hps_pcie_hip_avmm_hip_serial_rx_in3
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to hps_pcie_hip_avmm_hip_serial_rx_in3
set_location_assignment PIN_AT3 -to hps_pcie_hip_avmm_hip_serial_tx_out0
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to hps_pcie_hip_avmm_hip_serial_tx_out0
set_location_assignment PIN_AP3 -to hps_pcie_hip_avmm_hip_serial_tx_out1
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to hps_pcie_hip_avmm_hip_serial_tx_out1
set_location_assignment PIN_AM3 -to hps_pcie_hip_avmm_hip_serial_tx_out2
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to hps_pcie_hip_avmm_hip_serial_tx_out2
set_location_assignment PIN_AK3 -to hps_pcie_hip_avmm_hip_serial_tx_out3
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to hps_pcie_hip_avmm_hip_serial_tx_out3
set_location_assignment PIN_AT4 -to "hps_pcie_hip_avmm_hip_serial_tx_out0(n)"
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to "hps_pcie_hip_avmm_hip_serial_tx_out0(n)"
set_location_assignment PIN_AP4 -to "hps_pcie_hip_avmm_hip_serial_tx_out1(n)"
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to "hps_pcie_hip_avmm_hip_serial_tx_out1(n)"
set_location_assignment PIN_AM4 -to "hps_pcie_hip_avmm_hip_serial_tx_out2(n)"
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to "hps_pcie_hip_avmm_hip_serial_tx_out2(n)"
set_location_assignment PIN_AK4 -to "hps_pcie_hip_avmm_hip_serial_tx_out3(n)"
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to "hps_pcie_hip_avmm_hip_serial_tx_out3(n)"
set_location_assignment PIN_AF7 -to "hps_pcie_hip_avmm_refclk_clk(n)"
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to "hps_pcie_hip_avmm_refclk_clk(n)"
set_location_assignment PIN_AU2 -to "hps_pcie_hip_avmm_hip_serial_rx_in0(n)"
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to "hps_pcie_hip_avmm_hip_serial_rx_in0(n)"
set_location_assignment PIN_AR2 -to "hps_pcie_hip_avmm_hip_serial_rx_in1(n)"
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to "hps_pcie_hip_avmm_hip_serial_rx_in1(n)"
set_location_assignment PIN_AN2 -to "hps_pcie_hip_avmm_hip_serial_rx_in2(n)"
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to "hps_pcie_hip_avmm_hip_serial_rx_in2(n)"
set_location_assignment PIN_AL2 -to "hps_pcie_hip_avmm_hip_serial_rx_in3(n)"
set_instance_assignment -name IO_STANDARD "1.5-V PCML" -to "hps_pcie_hip_avmm_hip_serial_rx_in3(n)"
set_location_assignment PIN_AH21 -to pcie_perstn_out
set_instance_assignment -name AUTO_OPEN_DRAIN_PINS ON -to pcie_perstn_out
}

# instance assignments
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_uart0_RX
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_uart0_TX
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_uart1_RX
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_uart1_TX
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_CLK
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_D0
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_D1
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_D2
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_D3
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_D4
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_D5
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_D6
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_D7
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_DIR
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_NXT
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_usb1_STP
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO00
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO17
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO18
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO22
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO24
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO26
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO27
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO35
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO40
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO41
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO42
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_gpio_GPIO43
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_MDC
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_MDIO
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_RXD0
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_RXD1
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_RXD2
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_RXD3
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_RX_CLK
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_RX_CTL
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_TXD0
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_TXD1
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_TXD2
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_TXD3
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_TX_CLK
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_emac1_TX_CTL
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_i2c0_SCL
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_i2c0_SDA
set_instance_assignment -name WEAK_PULL_UP_RESISTOR ON -to hps_i2c0_SCL
set_instance_assignment -name WEAK_PULL_UP_RESISTOR ON -to hps_i2c0_SDA
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_qspi_CLK
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_qspi_IO0
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_qspi_IO1
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_qspi_IO2
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_qspi_IO3
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_qspi_SS0
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_sdio_CLK
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_sdio_CMD
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_sdio_D0
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_sdio_D1
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_sdio_D2
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_sdio_D3
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_trace_CLK
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_trace_D0
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_trace_D1
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_trace_D2
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_trace_D3
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_trace_D4
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_trace_D5
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_trace_D6
set_instance_assignment -name IO_STANDARD "3.3-V LVTTL" -to hps_trace_D7
set_instance_assignment -name CURRENT_STRENGTH_NEW "MAXIMUM CURRENT" -to hps_trace_CLK
set_instance_assignment -name CURRENT_STRENGTH_NEW "MAXIMUM CURRENT" -to hps_trace_D0
set_instance_assignment -name CURRENT_STRENGTH_NEW "MAXIMUM CURRENT" -to hps_trace_D1
set_instance_assignment -name CURRENT_STRENGTH_NEW "MAXIMUM CURRENT" -to hps_trace_D2
set_instance_assignment -name CURRENT_STRENGTH_NEW "MAXIMUM CURRENT" -to hps_trace_D3
set_instance_assignment -name CURRENT_STRENGTH_NEW "MAXIMUM CURRENT" -to hps_trace_D4
set_instance_assignment -name CURRENT_STRENGTH_NEW "MAXIMUM CURRENT" -to hps_trace_D5
set_instance_assignment -name CURRENT_STRENGTH_NEW "MAXIMUM CURRENT" -to hps_trace_D6
set_instance_assignment -name CURRENT_STRENGTH_NEW "MAXIMUM CURRENT" -to hps_trace_D7
set_instance_assignment -name SLEW_RATE 1 -to hps_trace_CLK
set_instance_assignment -name SLEW_RATE 1 -to hps_trace_D0
set_instance_assignment -name SLEW_RATE 1 -to hps_trace_D1
set_instance_assignment -name SLEW_RATE 1 -to hps_trace_D2
set_instance_assignment -name SLEW_RATE 1 -to hps_trace_D3
set_instance_assignment -name SLEW_RATE 1 -to hps_trace_D4
set_instance_assignment -name SLEW_RATE 1 -to hps_trace_D5
set_instance_assignment -name SLEW_RATE 1 -to hps_trace_D6
set_instance_assignment -name SLEW_RATE 1 -to hps_trace_D7
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_button_pio[3]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_button_pio[2]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_button_pio[1]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_button_pio[0]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_clk_50
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_dipsw_pio[3]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_dipsw_pio[2]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_dipsw_pio[1]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_dipsw_pio[0]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_led_pio[3]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_led_pio[2]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_led_pio[1]
set_instance_assignment -name IO_STANDARD "1.5 V" -to fpga_led_pio[0]

# Back annotated HPS SDRAM pin assignments to avoid Critical Warning
set_location_assignment PIN_N9 -to hps_memory_mem_a[0]
set_location_assignment PIN_M9 -to hps_memory_mem_a[1]
set_location_assignment PIN_N10 -to hps_memory_mem_a[2]
set_location_assignment PIN_M10 -to hps_memory_mem_a[3]
set_location_assignment PIN_A8 -to hps_memory_mem_a[4]
set_location_assignment PIN_B7 -to hps_memory_mem_a[5]
set_location_assignment PIN_B9 -to hps_memory_mem_a[6]
set_location_assignment PIN_A9 -to hps_memory_mem_a[7]
set_location_assignment PIN_D9 -to hps_memory_mem_a[8]
set_location_assignment PIN_C10 -to hps_memory_mem_a[9]
set_location_assignment PIN_K7 -to hps_memory_mem_a[10]
set_location_assignment PIN_J7 -to hps_memory_mem_a[11]
set_location_assignment PIN_F9 -to hps_memory_mem_a[12]
set_location_assignment PIN_E9 -to hps_memory_mem_a[13]
set_location_assignment PIN_D11 -to hps_memory_mem_a[14]
set_location_assignment PIN_L7 -to hps_memory_mem_ba[0]
set_location_assignment PIN_C9 -to hps_memory_mem_ba[1]
set_location_assignment PIN_D8 -to hps_memory_mem_ba[2]
set_location_assignment PIN_A11 -to hps_memory_mem_ck
set_location_assignment PIN_B10 -to hps_memory_mem_ck_n
set_location_assignment PIN_R8 -to hps_memory_mem_cke
set_location_assignment PIN_H9 -to hps_memory_mem_cs_n
set_location_assignment PIN_G8 -to hps_memory_mem_ras_n
set_location_assignment PIN_G9 -to hps_memory_mem_cas_n
set_location_assignment PIN_J8 -to hps_memory_mem_we_n
set_location_assignment PIN_E3 -to hps_memory_mem_reset_n
set_location_assignment PIN_H7 -to hps_memory_mem_odt
set_location_assignment PIN_C6 -to hps_memory_mem_dm[0]
set_location_assignment PIN_E4 -to hps_memory_mem_dm[1]
set_location_assignment PIN_D3 -to hps_memory_mem_dm[2]
set_location_assignment PIN_D1 -to hps_memory_mem_dm[3]
set_location_assignment PIN_T7 -to hps_memory_mem_dm[4]
set_location_assignment PIN_D7 -to hps_memory_mem_dq[0]
set_location_assignment PIN_C7 -to hps_memory_mem_dq[1]
set_location_assignment PIN_R10 -to hps_memory_mem_dq[2]
set_location_assignment PIN_G7 -to hps_memory_mem_dq[3]
set_location_assignment PIN_A6 -to hps_memory_mem_dq[4]
set_location_assignment PIN_A7 -to hps_memory_mem_dq[5]
set_location_assignment PIN_L6 -to hps_memory_mem_dq[6]
set_location_assignment PIN_D6 -to hps_memory_mem_dq[7]
set_location_assignment PIN_H6 -to hps_memory_mem_dq[8]
set_location_assignment PIN_G6 -to hps_memory_mem_dq[9]
set_location_assignment PIN_N8 -to hps_memory_mem_dq[10]
set_location_assignment PIN_G5 -to hps_memory_mem_dq[11]
set_location_assignment PIN_A4 -to hps_memory_mem_dq[12]
set_location_assignment PIN_A5 -to hps_memory_mem_dq[13]
set_location_assignment PIN_R9 -to hps_memory_mem_dq[14]
set_location_assignment PIN_F4 -to hps_memory_mem_dq[15]
set_location_assignment PIN_J5 -to hps_memory_mem_dq[16]
set_location_assignment PIN_K5 -to hps_memory_mem_dq[17]
set_location_assignment PIN_N7 -to hps_memory_mem_dq[18]
set_location_assignment PIN_F3 -to hps_memory_mem_dq[19]
set_location_assignment PIN_H3 -to hps_memory_mem_dq[20]
set_location_assignment PIN_J4 -to hps_memory_mem_dq[21]
set_location_assignment PIN_M5 -to hps_memory_mem_dq[22]
set_location_assignment PIN_C3 -to hps_memory_mem_dq[23]
set_location_assignment PIN_A2 -to hps_memory_mem_dq[24]
set_location_assignment PIN_A3 -to hps_memory_mem_dq[25]
set_location_assignment PIN_P7 -to hps_memory_mem_dq[26]
set_location_assignment PIN_C1 -to hps_memory_mem_dq[27]
set_location_assignment PIN_G2 -to hps_memory_mem_dq[28]
set_location_assignment PIN_F2 -to hps_memory_mem_dq[29]
set_location_assignment PIN_M3 -to hps_memory_mem_dq[30]
set_location_assignment PIN_E1 -to hps_memory_mem_dq[31]
set_location_assignment PIN_G1 -to hps_memory_mem_dq[32]
set_location_assignment PIN_F1 -to hps_memory_mem_dq[33]
set_location_assignment PIN_P6 -to hps_memory_mem_dq[34]
set_location_assignment PIN_L1 -to hps_memory_mem_dq[35]
set_location_assignment PIN_M2 -to hps_memory_mem_dq[36]
set_location_assignment PIN_M1 -to hps_memory_mem_dq[37]
set_location_assignment PIN_N1 -to hps_memory_mem_dq[38]
set_location_assignment PIN_R6 -to hps_memory_mem_dq[39]
set_location_assignment PIN_F7 -to hps_memory_mem_dqs[0]
set_location_assignment PIN_D5 -to hps_memory_mem_dqs[1]
set_location_assignment PIN_G4 -to hps_memory_mem_dqs[2]
set_location_assignment PIN_C2 -to hps_memory_mem_dqs[3]
set_location_assignment PIN_J1 -to hps_memory_mem_dqs[4]
set_location_assignment PIN_E7 -to hps_memory_mem_dqs_n[0]
set_location_assignment PIN_E6 -to hps_memory_mem_dqs_n[1]
set_location_assignment PIN_H4 -to hps_memory_mem_dqs_n[2]
set_location_assignment PIN_D2 -to hps_memory_mem_dqs_n[3]
set_location_assignment PIN_H1 -to hps_memory_mem_dqs_n[4]
set_location_assignment PIN_K9 -to hps_memory_oct_rzqin

project_close

